@@ -29,6 +29,8 @@ default_dirs = {
 default_files = {
     'after_reload_script': "/usr/local/bin/after-odoo-reload.sh",
     'after_up_script': "/usr/local/bin/after-odoo-up.sh",
+    'odoo_config_file_additions': "~/.odoo/odoo.config",
+    'odoo_config_file_additions.project': "~/.odoo/odoo.config.${project_name}",
     'project_settings': "~/.odoo/settings.${project_name}",
     'project_docker_compose.home': "~/.odoo/docker-compose.yml",
     'project_docker_compose.home.project': "~/.odoo/docker-compose.${project_name}.yml",
